@@ -3,21 +3,20 @@ package Geo::Coder::Many;
 use strict;
 use warnings;
 use Carp;
+use Data::Dumper;
 use List::MoreUtils qw(any);
 use Sort::Versions;
+use HTTP::Response;
 use Time::HiRes;
 
-our $VERSION = 0.46;
+our $VERSION = '0.47';
 
 # note - also update lists far below in pod
 use Geo::Coder::Many::Bing;
-use Geo::Coder::Many::Google;
 use Geo::Coder::Many::Googlev3;
 use Geo::Coder::Many::Mapquest;
 use Geo::Coder::Many::OpenCage;
 use Geo::Coder::Many::OSM;
-use Geo::Coder::Many::Ovi;
-use Geo::Coder::Many::PlaceFinder;
 
 use Geo::Coder::Many::Util qw(
     min_precision_filter 
@@ -33,10 +32,13 @@ use Geo::Coder::Many::Scheduler::UniquenessScheduler::WeightedRandom;
 
 =head1 NAME
 
-Geo::Coder::Many - Module to tie together multiple Geo::Coder::* modules
+Geo::Coder::Many - Module to tie together multiple Geo::Coder::* modules.
+NOTE: this module is DEPRECATED and no longer maintained.
 
 =head1 DESCRIPTION
 
+This module is no longer maintained and we advise not to use it.
+
 Geo::Coder::Many provides a single interface to different remote 
 (ie HTTP based) geocoding modules
 
@@ -430,7 +432,7 @@ sub geocode {
             $args->{cache},
         );
         if ( defined $response ){
-            return $response 
+            return $response;
         }
     }
 
@@ -482,7 +484,6 @@ sub geocode {
 
         # Tell the scheduler about how successful the geocoder was
         if (defined $Response) {
-
             my $feedback = { 
                 response_code => $Response->get_response_code(),
             };
@@ -496,7 +497,7 @@ sub geocode {
 
         # If our response has a valid code
         if ( $self->_response_valid($Response) ) {
-            
+
             # Apply the filter callback to the response entries
             my @passed_responses = grep { 
                 $self->_passes_filter($_)
@@ -536,7 +537,8 @@ sub geocode {
                 $accepted_response = $self->_form_response( 
                     $passed_responses[0], 
                     $Response 
-                );
+                    );
+
             }
 
         }
@@ -547,7 +549,7 @@ sub geocode {
     if (defined ($self->{picker_callback}) && !defined $accepted_response ) {
         $accepted_response = $self->{picker_callback}->( $ra_valid_results, 0 );
     }
-
+    
     # If we're using a cache and we have a good response, let's cache it.
     if ( !$args->{no_cache} ) {
         $self->_set_in_cache(
@@ -556,7 +558,6 @@ sub geocode {
             $args->{cache} 
         );
     }
-
     return $accepted_response;
 }
 
@@ -854,24 +855,18 @@ C<geocode> method which takes a single location string as an argument.
 Currently supported Geo::Coder::* modules are:
 
   Geo::Coder::Bing
-  Geo::Coder::Google
   Geo::Coder::Googlev3
   Geo::Coder::Mapquest
   Geo::Coder::OpenCage
   Geo::Coder::OSM
-  Geo::Coder::Ovi
-  Geo::Coder::PlaceFinder
 
 =head1 SEE ALSO
 
   Geo::Coder::Bing
-  Geo::Coder::Google
   Geo::Coder::Googlev3
   Geo::Coder::Mapquest
   Geo::Coder::OpenCage
   Geo::Coder::OSM
-  Geo::Coder::Ovi
-  Geo::Coder::PlaceFinder
 
 Ed Freyfogle delivered a talk about Remote Geocoding and the
 motivation for Geo::Coder::Many at the 2010 London Perl
@@ -882,8 +877,8 @@ http://www.slideshare.net/lokku/remote-geocoding
 
 Originally Dan Horgan (http://search.cpan.org/~danhgn/) 
 
-This module is maintained by the team members of Lokku
-Ltd. (http://www.lokku.com)
+This module is no longer maintained by the team members of OpenCage Data Ltd
+Ltd. (http://www.opencagedata.com)
 
 Geo::Coder::Many was originally based on Geo::Coder::Multiple, which
 unfortunately seems to no longer be maintained, by Alistair Francis
@@ -891,8 +886,7 @@ http://search.cpan.org/~friffin/
 
 =head1 FEEDBACK
 
-Patches are encouraged! Please fork on github (ideally with tests) or send
-feedback to cpan@lokku.com
+Please get in touch if you'd like to takeover ownership of this module
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -903,23 +897,16 @@ http://blog.timbunce.org/2010/06/09/high-quality-multi-source-geocoding-in-perl/
 Needless to say, neither he nor anybody else should be held responsible for
 any deficiencies in the implementation!
 
-=head1 YOU MAY ALSO ENJOY
-
-If reducing your dependancy on geo information providers is your thing - and 
-really, who doesn't enjoy breaking dependancy? - then you will probably like 
-Mapstraction - http://mapstraction.com
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Lokku Ltd <cpan@lokku.com>
+Copyright 2017 Opencage Data Ltd <cpan@opencagedata.com>
 
-Please check out all our open source work over at https://github.com/lokku and 
-our developer blog: http://devblog.nestoria.com
+Please check out all our open source work over at 
+https://github.com/opencagedata
 
 Thanks!
 
 Parts taken from Geo::Coder::Multiple are copyright 2009 Alistair Francis
-<opensource@alizta.com>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10 or,
